pub async fn get_titles_by_ids(
conn: &mut PgConnection,
page_ids: &[Uuid],
) -> ModelResult<HashMap<Uuid, String>>Expand description
Titles for a set of pages, for annotating rows that only carry a page id.
pub async fn get_titles_by_ids(
conn: &mut PgConnection,
page_ids: &[Uuid],
) -> ModelResult<HashMap<Uuid, String>>Titles for a set of pages, for annotating rows that only carry a page id.